summaryrefslogtreecommitdiff
path: root/test/java/net
diff options
context:
space:
mode:
authorMichael Peter Christen <mc@yacy.net>2026-07-11 11:11:06 +0200
committerMichael Peter Christen <mc@yacy.net>2026-07-11 11:11:06 +0200
commitb1380c4a9f479de4fc456b6305bee57bc752ad03 (patch)
treec0d42fb103edafa5e9b8e5f04f48bfdcc658441e /test/java/net
parentf2b0f41d8492ebf92b0e331e8c9c78e626f371c9 (diff)
cleaned up user authentication
this removes the userDB-exception in the normal authentication process which affected mostly wiki and blog which are not required any more. We also cleaned up translation messages as this function was not used at all. This is a required step forward a renovation of the jetty server.
Diffstat (limited to 'test/java/net')
-rw-r--r--test/java/net/yacy/data/wiki/WikiCodeTest.java37
1 files changed, 18 insertions, 19 deletions
diff --git a/test/java/net/yacy/data/wiki/WikiCodeTest.java b/test/java/net/yacy/data/wiki/WikiCodeTest.java
index 8a1d69346..b221090f4 100644
--- a/test/java/net/yacy/data/wiki/WikiCodeTest.java
+++ b/test/java/net/yacy/data/wiki/WikiCodeTest.java
@@ -140,25 +140,24 @@ public class WikiCodeTest {
* Test internal link markup processing
*/
@Test
- public void testInternalLink() {
- WikiCode wc = new WikiCode();
-
- /* Link to another wiki article */
- String result = wc.transform("http://wiki:8080", "[[article]]");
- assertTrue(result.contains("<a"));
- assertTrue(result.contains("href=\"Wiki.html?page=article\""));
-
- /* Renamed link */
- result = wc.transform("http://wiki:8080", "[[article|renamed article]]");
- assertTrue(result.contains("<a"));
- assertTrue(result.contains("href=\"Wiki.html?page=article\""));
- assertTrue(result.contains(">renamed article<"));
-
- /* Multiple links on the same line */
- result = wc.transform("http://wiki:8080", "[[article1]] [[article2]]");
- assertTrue(result.contains("<a"));
- assertTrue(result.contains("href=\"Wiki.html?page=article1\""));
- assertTrue(result.contains("href=\"Wiki.html?page=article2\""));
+ public void testRetiredInternalLinkRendersLabelOnly() {
+ WikiCode wc = new WikiCode();
+
+ /* Internal links no longer target the retired local Wiki application. */
+ String result = wc.transform("http://wiki:8080", "[[article]]");
+ assertFalse(result.contains("<a"));
+ assertTrue(result.contains("article"));
+
+ /* Renamed link */
+ result = wc.transform("http://wiki:8080", "[[article|renamed article]]");
+ assertFalse(result.contains("<a"));
+ assertTrue(result.contains("renamed article"));
+
+ /* Multiple links on the same line */
+ result = wc.transform("http://wiki:8080", "[[article1]] [[article2]]");
+ assertFalse(result.contains("<a"));
+ assertTrue(result.contains("article1"));
+ assertTrue(result.contains("article2"));
}
/**